#!/bin/bash

# This script set basic environment variables for the project

ENV_DIRECTORY="./env" # Replace with your directory path

echo "Preparing environment variables for directory: $ENV_DIRECTORY"

# List files ending with .tfvars and remove the extension
env_list=($(ls $ENV_DIRECTORY/*.tfvars | xargs -n 1 basename | sed 's/\.tfvars$//'))

# Check if the list is empty
if [ ${#env_list[@]} -eq 0 ]; then
    echo "No .tfvars files found in the directory."
    exit 1
fi

# Function to display the list and get user choice
get_user_choice() {
    echo "Select an environment from the list:"
    select env_choice in "${env_list[@]}"; do
        # Check if the choice is valid
        if [[ " ${env_list[*]} " =~ " ${env_choice} " ]]; then
            export TARGET_ENV="$env_choice"
            break
        else
            echo "Invalid selection. Please try again."
        fi
    done
}
# Call the function to get user choice
get_user_choice


get_variable_value() {
    local var_name=$1
    local var_keyvalue=$(grep "^$var_name" "$TF_VARIABLES_FILE" | tr -d ' ' | tr -d ' ' | awk -F '#' '{print $1}')
    local var_value=$(echo $var_keyvalue | awk -F'=' '{print $2}' | tr -d '"')
    if [ -z "$var_value" ]; then
        echo -e "\033[31mERROR ! $var_name variable is missing in $TF_VARIABLES_FILE \033[0m"
        exit 1
    fi
    echo "$var_value"
}


echo "Target Environment -> $TARGET_ENV"

export TF_VARIABLES_FILE=env/$TARGET_ENV.tfvars
echo "TF Variables File: $TF_VARIABLES_FILE"

#---------------------------------------
# Get State Bucket & File
#---------------------------------------
export TF_STATE_BUCKET=$(get_variable_value "tf_state_bucket")
if [ -z "$TF_STATE_BUCKET" ]; then
  echo -e "\033[31mERROR ! tf_state_bucket variable is missing in $TF_VARIABLES_FILE \033[0m"
  exit 1
fi
echo "TF State Bucket: $TF_STATE_BUCKET"

export TF_STATE_FILE=$(get_variable_value "tf_state_file")
if [ -z "$TF_STATE_FILE" ]; then
  echo -e "\033[31mERROR ! tf_state_file variable is missing in $TF_VARIABLES_FILE \033[0m"
  exit 1
fi
echo "TF State File: $TF_STATE_FILE"


#---------------------------------------
# Check if the target account and region are correct
#---------------------------------------
export TARGET_ACCOUNT=$(get_variable_value "account")
echo "Target Account -> $TARGET_ACCOUNT"

export TARGET_REGION=$(get_variable_value "region")
echo "Target Region -> $TARGET_REGION"

export ACTUAL_ACCOUNT=$(aws sts get-caller-identity --query Account --output text)
if [ "$TARGET_ACCOUNT" != "$ACTUAL_ACCOUNT" ]; then
  echo -e "\033[31mERROR ! WRONG TARGET ACCOUNT,  EXPECTING: $TARGET_ACCOUNT  GOT: $ACTUAL_ACCOUNT \033[0m"
  exit 1
fi

export ACTUAL_REGION=$(aws configure get region)
if [ "$TARGET_REGION" != "$ACTUAL_REGION" ]; then
  echo -e "\033[31mERROR ! WRONG TARGET REGION,  EXPECTING: $TARGET_REGION  GOT: $ACTUAL_REGION \033[0m"
  exit 1
fi

echo ""
